const ZeedhiAPIConstructor = require('zeedhi-functional-test-api');
const z = new ZeedhiAPIConstructor(browser, protractor);
const Helper = require('teknisa-helper');
const geral = new Helper.geral();
const loginPage = new Helper.login();
const protractorHelper = require('protractor-helper');
const j = require('../../../json/leitorJson.po.js');
const agenciaPage = require('../../../page-objects/parametrizacao/financeiro/agencia.po.js');

const agenciaGrid = '1927843453876122292522';
const contatoGrid = '19278434532905280706523';
const telefoneModificado = '31932285995';
describe('Tela Agência', () => {
	beforeAll(() => {
		browser.get('http://erpteste.teknisa.com/login/');
		loginPage.login(j.getValor('login'), j.getValor('senha'));
		agenciaPage.abrir();
		geral.esperarLoading();
		agenciaPage.selectBanco(j.getValor('banco'));
		protractorHelper.waitForElementVisibility(element(by.id(`grid-${agenciaGrid}`)), 5000);
	});

	afterAll(() => {
		geral.sair();
	});

	it('Acessar tela Agência', () => {
		expect(z.component.header.getTitle()).toBe('Agência');
	});

	it('Adicionar nova Agência', () => {
		geral.clickAdicionar();
		agenciaPage.adicionaAgencia(j.getValor('codigoAgen'), j.getValor('nomeAgen'),
			j.getValor('cnpj'), j.getValor('cep'), j.getValor('telefone'), j.getValor('fax'));

		expect(geral.gridHasText(agenciaGrid, j.getValor('nomeAgen'), 1))
			.toBe(j.getValor('nomeAgen'));

		geral.clickGrid('NMAGENCIA', j.getValor('nomeAgen'), agenciaGrid);

		expect(z.widget.formView.getFieldValue('NMPAIS'))
			.toBe(j.getValor('pais'));
		expect(z.widget.formView.getFieldValue('NMBANCO'))
			.toBe(j.getValor('banco'));
		expect(z.widget.formView.getFieldValue('NMAGENCIA'))
			.toBe(j.getValor('nomeAgen'));
		geral.clickVoltar();
	});

	it('Adicionar Contanto', () => {
		geral.clickGrid('NMAGENCIA', j.getValor('nomeAgen'), agenciaGrid);
		agenciaPage.adicionaContato(j.getValor('nomePessoa'), j.getValor('cargo'),
			j.getValor('telefone'));

		expect(geral.gridHasText(contatoGrid, j.getValor('nomePessoa')))
			.toBe(j.getValor('nomePessoa'));
		expect(geral.gridHasText(contatoGrid, j.getValor('cargo'), 1))
			.toBe(j.getValor('cargo'));
		expect(geral.gridHasText(contatoGrid, Helper.util.formataTelefone(j.getValor('telefone')), 2))
			.toBe(Helper.util.formataTelefone(j.getValor('telefone')));
		geral.clickVoltar();
	});

	it('Alterar Agência', () => {
		const faxModificado = j.getValor('fax').substr(0, 8).concat(99);

		geral.clickGrid('NMAGENCIA', j.getValor('nomeAgen'), agenciaGrid);
		agenciaPage.alteraAgencia(j.getValor('nomeAgen1'), j.getValor('cnpj2'),
			j.getValor('cep2'), telefoneModificado, faxModificado);

		expect(z.widget.formView.getFieldValue('NMBANCO'))
			.toBe(j.getValor('banco'));
		expect(z.widget.formView.getFieldValue('NMAGENCIA'))
			.toBe(j.getValor('nomeAgen1'));
		geral.clickVoltar();
	});

	it('Alterar Contato', () => {
		const cargoModificado = j.getValor('cargo').concat(' Fin');

		geral.clickGrid('NMAGENCIA', j.getValor('nomeAgen1'), agenciaGrid);
		geral.trocarAba('Contato');
		protractorHelper.waitForElementVisibility(element(by.id('grid-' + contatoGrid)), 5000);
		geral.clickGrid('NMCONTAGEN', j.getValor('nomePessoa'), contatoGrid);
		agenciaPage.alteraContato(cargoModificado, telefoneModificado);
		geral.clickVoltar();

		expect(geral.gridHasText(contatoGrid, cargoModificado, 1))
			.toBe(cargoModificado);
		expect(geral.gridHasText(contatoGrid, Helper.util.formataTelefone(telefoneModificado), 2))
			.toBe(Helper.util.formataTelefone(telefoneModificado));
		geral.clickVoltar();
	});

	it('Excluir Contato', () => {
		geral.clickGrid('NMAGENCIA', j.getValor('nomeAgen1'), agenciaGrid);
		geral.trocarAba('Contato');
		geral.clickGrid('NMCONTAGEN', j.getValor('nomePessoa'), contatoGrid);
		geral.clickExcluir();
		geral.clickSim();

		expect(geral.gridHasText(contatoGrid, j.getValor('nomePessoa')))
			.toBeUndefined();
		expect(geral.gridHasText(contatoGrid, j.getValor('cargo2'), 1))
			.toBeUndefined();
		expect(geral.gridHasText(contatoGrid, Helper.util.formataTelefone(j.getValor('telefone')), 2))
			.toBeUndefined();
		geral.clickVoltar();
	});

	it('Excluir Agência', () => {
		geral.clickGrid('NMAGENCIA', j.getValor('nomeAgen1'), agenciaGrid);
		geral.clickExcluir();
		geral.clickSim();

		expect(geral.gridHasText(agenciaGrid, j.getValor('nomeAgen1'), 1))
			.toBeUndefined();
	});
});
